/**
 * Ubuntu Core Front-End Framework
 *
 * Core javascript file part of Ubuntu Core Front-End Framework
 * 
 * This file containes the classes required by ubuntu.com to interact. 
 * 
 * @project		Ubuntu Core Front-End Framework
 * @author		Web Team at Canonical Ltd
 * @copyright	2012 Canonical Ltd
 *
 */

/**
 * Table of contents
 *
 * Core
 * - setEqualHeight
 * - getPullQuotes
 * - searchInteraction
 * - hashBang
 *  -- qualifyURL
 *  -- checkForSession
 *  -- slideToAnchor
 *  -- jumpToAnchor
 * - setupTooltips
 * - setupFeatureDisplay
 * 
 */

var debug = true;
var errorSystem = new ErrorSystem(debug);

core = {};

core.setEqualHeight = function($className) {
   YUI().use('node', function (Y) {
	    var maxHeight = 0;
	    var heightArray = Array();
	    var collection = Y.all('.'+$className);
	    errorSystem.report("Running setEqualHeight","Found " + collection._nodes.length );
	    collection.each(function(node) {
	    	node.all(' > div, > ul').each(function(node) {
	    		if(node.one('> div, > ul') != null){
			    	var currentHeight = parseFloat(node.all('> div, > ul').getComputedStyle('height')[0].replace('px',''));
			    	if(currentHeight > maxHeight){
			    		maxHeight = currentHeight;
			    	}
			    }
	    	});
	    	node.all(' > div, > ul').each(function(node) {
	    		node.all('> div, > ul li').setStyle('height', maxHeight);
	    	});
	    	maxHeight = 0;
	    });
	});
}

core.getPullQuotes = function() {
	YUI().use('node', function(Y) {
	    Y.all('span.pull-quote').each(function (node) {
	       var item = Y.Node.create('<div class="pull-quote">&quot;'+node.getContent()+'&quot;</div>');
	       node.get('parentNode').get('parentNode').get('parentNode').append(item);
	    });
	});
}

core.searchInteraction = function() {
   YUI().use('event', function (Y) {
   		var searchBox = Y.one('#edit-keys');
   		searchBox.set("value","Type to search");
	    searchBox.on('blur', function(e) {
	    	if(searchBox.get('value') == ""){
	    		searchBox.set("value","Type to search");
	    	}
	    });
	    searchBox.on('focus', function(e) {
	    	if(searchBox.get('value') == "Type to search"){
	    		searchBox.set("value","");
	    	}
	    });
	});
}

core.hashBang = function() {
	YUI().use('node', function(Y) {
		Y.all('a').each(function (node) {
			var hrefValue = node.get('href');
			if( hrefValue.indexOf("#") != -1 ){
				var cleanTarget = core.qualifyURL(hrefValue.substr(0,hrefValue.indexOf('#')));
				var hashValue = hrefValue.substr(hrefValue.indexOf('#')+1);
				var cleanURL = window.location.href;
				node.setAttribute('data-hash',hashValue);
				node.set('href',hrefValue.substr(0,hrefValue.indexOf('#')));
				if(cleanURL == cleanTarget){
					node.on("click", function (e) {
						e.preventDefault();
						window.name = null;
						core.slideToAnchor(this.getAttribute('data-hash'));
					});
				}else{
					node.on("click", function (e) {
						window.name = '¬'+node.getAttribute('data-hash');
					});
				}
			}else{
				node.on("click", function (e) {
					window.name = null;
				});
			}
		});
	});
	core.checkForSession();
}

core.qualifyURL = function($url) {
    var img = document.createElement('img');
    img.src = $url;
    $url = img.src;
    img.src = null;
    img = null;
    return $url;
}

core.checkForSession = function() {
	var session = window.name;
	if(session.charAt(0) == '¬'){
		core.jumpToAnchor(session.substring(1));
	}
}

core.slideToAnchor = function($name) {
	var target;
	YUI().use('anim', function (Y) {
		if($name == ''){
			target = Y.one('#main-content');
		}else{
			target = Y.one('#'+$name);
		}
		var myAnim = new Y.Anim({
		    node: 'body, html',
		    to: { scrollTop: target.getXY()[1] },
		    easing: 'easeOut'
		}, 2000);
		myAnim.run(2000);
	});
}

core.jumpToAnchor = function($name) {
	if(document.getElementById($name)){
		document.getElementById($name).scrollIntoView();
	}else{
		console.log('Error: Could not find ID: '+$name);
		window.name = null;
	}
}

core.setupTooltips = function() {
	YUI().use('node', function(Y) {
		if(Y.one('.tooltip') != null) {
			Y.all('.tooltip').each(function (node) {
				node.get('parentNode').prepend('<p class="tooltip-label">'+node.get('title')+'</p>');
				var title = this.get('title');
				node.on('mouseover', function(e){
					this.set('title','');
					this.get('parentNode').one('.tooltip-label').setStyle('display', 'inline');
				});
				node.on('mouseout', function(e){
					this.set('title',title);
					this.get('parentNode').one('.tooltip-label').setStyle('display', 'none');
				});
			});
		}
	});
}

core.setupFeatureDisplay = function() {
	YUI().use('node', function(Y) {
		if(Y.one('.list-features-content') != null) {
			Y.all('.list-features-content li').setStyle('display','none');
			Y.one('#list-feature-saas').setStyle('display','block');
			Y.all('.nav-list-features li').each(function (node) {
				node.delegate('click', function(e){
					e.preventDefault();
		        	var clicked = this.get('text');
		        	Y.all('.nav-list-features li a').removeClass('active');
		      		this.addClass('active');
		        	var toShow = '';
		        	switch(clicked) {
		        		case 'SAAS':
		        			toShow = '#list-feature-saas';
		        		break;
		         		case 'Service orchestration':
		        			toShow = '#list-feature-orchestration';
		        		break;
		         		case 'PAAS':
		        			toShow = '#list-feature-paas';
		        		break;
		         		case 'Guest OS':
		        			toShow = '#list-feature-guest';
		        		break;
		         		case 'Public cloud':
		        			toShow = '#list-feature-public';
		        		break;
		         		case 'Private cloud':
		        			toShow = '#list-feature-private';
		        		break;
		         		case 'Virtualisation':
		        			toShow = '#list-feature-virtualisation';
		        		break;
		       		}
		       		Y.all('.list-features-content li').setStyle('display','none');
		        	Y.one(toShow).setStyle('display','block');
		        }, 'a');
		    });
	   }
	});
}

core.setEqualHeight('row-equal-height');
core.searchInteraction();
core.hashBang();
core.setupTooltips();
core.setupFeatureDisplay();

